@@ -18,6 +18,7 @@ parameter_types = [
     "int",
     "string",
     "enum",
+    "enum_list",
 ]
 help_schema = {
     "oneof_schema": [
@@ -32,7 +33,9 @@ parameter_field_schema = {
     "help": help_schema.copy(),
     "collapsed": {"required": False, "type": "boolean"},
     "required": {"required": False, "type": "boolean"},
-    "choices": {"dependencies": {"type": ["enum"]}, "type": "list"},
+    "choices": {"dependencies": {"type": ["enum", "enum_list"]}, "type": "list"},
+    "default_choices": {"dependencies": {"type": ["enum_list"]}, "type": "list"},
+    "display_type": {"dependencies": {"type": ["enum_list"]}, "type": "string"},
     "connection_type_uuid": {"dependencies": {"type": ["connection"]}, "type": "string"},
     "name": {"type": "string", "required": True},
     "dialect": {
@@ -54,9 +57,9 @@ parameter_field_schema = {
             # E.G. a field that is a "connection" type must have "connection_type_uuid" as a parameter.
             {"allowed": ["connection"], "dependencies": "connection_type_uuid"},
             {"allowed": ["code", "sql"], "dependencies": "dialect"},
-            {"allowed": ["enum"], "dependencies": "choices"},
+            {"allowed": ["enum", "enum_list"], "dependencies": "choices"},
             # Add above bi-lateral dependencies as "forbidden" so above dependencies are evaluated only once.
-            {"forbidden": ["connection", "code", "sql", "enum"]},
+            {"forbidden": ["connection", "code", "sql", "enum", "enum_list"]},
         ],
     },
     "shared_object_type_uuid": {"type": "string", "required": False},
@@ -87,7 +90,7 @@ engine_schema = {
         "type": "string",
         "minlength": 8,
         "required": True,
-        "regex": r"^[A-Z\d]+-[A-Z\d]+$",
+        "regex": r"^[A-Z0-9]+([_-][A-Z0-9]+)*$",
     },
     "icons": {
         "type": "dict",
